@@ -136,6 +136,7 @@ class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSpace {
   friend class SynthonSpaceSearcher;
   friend class SynthonSpaceFingerprintSearcher;
   friend class SynthonSpaceRascalSearcher;
+  friend class SynthonSpaceSubstructureSearcher;
 
  public:
   explicit SynthonSpace() = default;
@@ -380,11 +381,12 @@ class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSpace {
 
  protected:
   unsigned int getMaxNumSynthons() const { return d_maxNumSynthons; }
-
+  unsigned int getMaxNumConnectors() const;
   bool hasFingerprints() const;
 
   bool hasAddAndSubstractFingerprints() const;
-
+  // Return whether the space contains a ring-forming reaction.
+  bool getHasRingFormer() const { return d_hasRingFormer; }
   // Take the SMILES for a Synthon and if it's not in
   // d_synthonPool make it and add it.  If it is in the pool,
   // just look it up.  Either way, return a pointer to the
@@ -422,6 +424,9 @@ class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSpace {
   // creating synthon fingerprints that are read from a binary file.
   std::string d_fpType;
 
+  // Whether there is a ring-forming reaction in the space.
+  bool d_hasRingFormer{false};
+
   SearchResults extendedSearch(const MolBundle &query,
                                const SubstructMatchParameters &matchParams,
                                const SynthonSpaceSearchParams &params);
